# It is possible to pass %update value
# in the command line args to rpmbuild.
%if "%{?update:1}" == ""
%define update 0
%endif

%define baseversion 4.58
%define ALTReleaseNo 2

%if "%update" != "0"
%define release alt0.update%update.%ALTReleaseNo
%endif

# It is possible to pass %release value
# in the command line args to rpmbuild.
%if "%{?release:1}" == ""
%define release alt%ALTReleaseNo
%endif


# Otherwise we get too many unimportant warnings
%define optflags_warnings -Wundef -Wformat
%define WithRecode 1

%define WithSSL 1
%if "%_without_ssl" == "--without-ssl"
%define WithSSL 0
%endif

# Don't forget to edit the description & summary if you change this:
%define WithMaildir 1
%if "%_without_maildir" == "--without-maildir"
%define WithMaildir 0
%endif

%define WithDebug 0
%add_optflags %optflags_debug
%if 0
%remove_optflags %optflags_optimization
%endif

%define MergeConfPostInstall 1
%if "%update" != "0"
%define MergeConfPostInstall 0
%endif

# The packaging of the package should be a little cumbersome:
# the main PINE package must be built & packaged for specific arch's,
# but the tools subpackage is platform-independent (just scripts),
# so a "noarch" package must be made. The difference occurs only on the
# stage of making package files.

%define mainsummary A commonly used, MIME compliant mail and news reader.
%define name pine
%define exec %_bindir/%name
%define section Networking/Mail

%if %WithRecode
%define fullversion %{baseversion}L
%else
%define fullversion %{baseversion}
%endif

%define utilver 1.0
%define utilrel ipl9

%define ldifver 0.1.4

Name: %name
Version: %fullversion
Release: %release.1
License: distributable
Group: %section
Summary: %mainsummary
Summary(ru_RU.KOI8-R):  ,  MIME      .
Url: http://www.washington.edu/%name
Packager: Ivan Zakharyaschev <imz@altlinux.org>

# For nice work PINE should be able to use a spell checker
# XXX Which one? Consider pspell, aspell, ispell
# TODO: Requires: spellchecker
Requires: %_bindir/spell

Requires: urlview

Requires(post): mktemp sed grep

%define mailspooldir %_var/mail
%if "%update" == "2.0"
%define mailspooldir %_var/spool/mail
%endif

# Fallback values if openssl-config is not available:
%define _ssldir %_localstatedir/ssl
%if "%update" == "2.0"
%define _ssldir %_libdir/ssl
%endif

%if %WithSSL

%if "%update" != "2.0"
# for openssl-config:
BuildRequires(build): openssl >= 0.9.6g-alt2
%define _ssldir %(openssl-config --openssldir)
%endif

# It seems that this is applicable only to the server,
# for the client the location is not important, comment out:
# the location of certificates is hardcoded into the binaries (hence Requires)
#Requires: /var/lib/ssl

%endif #WithSSL

%define _pemdir %_ssldir/certs

Source0: ftp://ftp.cac.washington.edu/%name/%name%baseversion.tar.bz

Source2: %name-4.55L-alt2-conf.ALT
Source3: %name.conf.fixed
Source5: %{name}_16x16.xpm
Source6: %{name}_32x32.xpm
Source7: %{name}_48x48.xpm
Source8: imap-c-client-maildir.tar.bz2

Source11: %name-4.58-UW-docs.tar.bz2
Source12: %name-4.42L-info.ALT
Source13: %name-4.42L-ALT-longinfo.txt
Source14: %name-utils.readme
Source15: %name-4.42-substitute_technotes.txt
Source16: %name-4.42-substitute_FAQ.txt

Source50: z-recoding-engine-0.4.1.tar

# non-UW utils:
Source101: http://www.Physik.Uni-Dortmund.DE/~wacker/elm-to-pine
Source102: pine2Mutt
Source103: http://www.muc.de/~sam/pub/pine/ldif2pine-%ldifver.tar.bz2
Source110: %name-addrbk-utils-1.0-run-pwd2pine.sh

# included for comparing with Mdk/RH, it isn't applied:
Patch0: pine4.30-RH-otherOS.patch
# for glibc 2.2.2
Patch1: uw-imap-2001a-glibc-time.patch
Patch7: pine-4.44L-tinfo.patch

Patch4: uw-imap-2001a-alt7-ALT-custom.patch

# XXX is sigchild patch still necessary???
#Patch3: pine-3.96-sigchld.patch
# redone for 4.30:
Patch3: pine4.30-sigchld.patch
# though it isn't applied

Patch5: pine-4.02-filter.patch

# The maildir support (turned on by %WithMaildir)
# is supplied by three source pieces:
# the tarball (Source8) with the module and README,
# a general patch that embeds the maildir module into the build
# process, and a patch special for Pine client (not the imap server).
Patch8: uw-imap-2001a-maildir-embed.patch

Patch2: uw-imap-maildir-glibc-time.patch
Patch9: pine-maildir-specialconf.patch

Patch6: uw-imap-2001a-alt7-flocksim.patch

Patch10: uw-imap-2002e-debian-portability.patch
Patch11: uw-imap-2001a-debian-nonull.patch
# moved to oldpatches/ in Debian (uw-imap_2002a.dev.snap.0212051126debian-2)
Patch12: uw-imap-2001a-debian-blackbox-inbox.patch
Patch13: uw-imap-2001a-overflow.patch

Patch15: pine4.10-c-client_directory_with_driver.patch

# patches 12, 13 from Mdk
# insetred into one of the "path"-patches

Patch14: pine-4.21-fixhome.patch

Patch17: uw-imap-2002e-alt-openssl.patch

Patch20: pine-4.55-boguswarning.patch

Patch21: pine-4.53-filter-local_nvtnl-reset.patch
# adjusting build rules (merged from Lev's and RedHat's patches):
Patch120: pine-4.51-ALT-build.patch
# Filesystem paths patch:
Patch121: pine-4.55-ALT-path.patch

# (Russian Edition) recode:
Patch130: pine-4.58L-alt2-0.4.1.diff
Patch131: pine-4.42L-0.2.3-hlp.fuzzy-patch

# Do not use libpam0-devel in Reqs -- for compatibility with 2.0:
# Automatically added by buildreq on Mon Sep 15 2003
BuildRequires: libpam-devel lynx mailcap

%if "%update" == "2.0"
BuildPreReq: libncurses-devel
%else
BuildPreReq: libtinfo-devel
%endif

%if %WithSSL
%if "%update" == "2.0"
BuildPreReq: openssl-devel
%else
BuildPreReq: libssl-devel
%endif
BuildPreReq: openssl
%endif #%WithSSL

%description
Pine is a very popular, easy to use, full-featured email user agent
which includes a simple text editor called pico. Pine supports MIME
extensions and can also be used to read news.  Pine also supports
IMAP, mail, MH and Maildir (used by qmail) style folders.

Pine should be installed to make possible managing mail in a text terminal;
its interface is rather handy in that sense that it allows you to start
using the program without reading any additional documenation. It is a very
commonly used email user agent and it is currently in development.

Be careful when using %name with Maildir folders: the Maildir support
is brought into %name by a non-native code and might not work as stable
as other functions.

%description -l ru_RU.KOI8-R
Pine ("") -- Program for Internet News & Email.  ,
  ,   
 (Mail User Agent),   
     pico. Pine 
 MIME;      .  
      mail, MH  Maildir ( 
 qmail),   ,   IMAP.

  ,         ;
   ,     ,  
 .   ;   
  .

 ,  %name     Maildir:
    %name     
  ,   .

%package doc
Summary: More documentation for %name.
Summary(ru_RU.KOI8-R):    %name.
Group: %section

# Documentation can be installed independently of binaries
# (to get acquainted, to print out, ...),
# but if the binaries are installed, the doc-pkg should correspond
# to their version. This is expressed by the following conflicts.
Conflicts: %name < %fullversion
Conflicts: %name > %fullversion

%description doc
Three major groups of the additional documentation that supplemets the
%name package are:
 - User guide (tutorial)
 - Technical notes
 - FAQs
 - historical notes.

There are also a few other minor doc-files not so important for the main package. Some
of the documentation is distributed along with the source of %name by UW
(University of Washington), some is published separately on their site.

The Technical Notes included can be of some interest and use not only
to PINE developers and hackers, but also (and even much more) for users
getting "advanced".

%description doc -l ru_RU.KOI8-R
  ,    , 
 %name, :
 -   ()
 -  
 - FAQs (Frequently Asked Questions --   )
 -  .

    ,     
   .    
 UW (University of Washington)   
%name,     .

 ,    ,    
 (   ) -  ,  
,   "".

%package addrbk-tools
Summary: A set of tools dealing with %name addressbook files.
Summary(ru_RU.KOI8-R):        (adress books) %name.
Group: File tools
Version: %utilver
Release: %utilrel.1
Prefix: %prefix
# It should be a "noarch" package

#
#There is a separate package with tools for mailbox conversions.

%description addrbk-tools
Most of these tools are scripts either contributed to Pine project or
written independently. All of them are intended to make PINE
addressbooks by extracting appropriate information from a file with account
information stored/used by another similar program (mail user agent).
A vice versa conversion may also be possible.

You should install %name-addrbk-tools if you wouldd like to migrate between %name
and Mutt, elm, mail, Netscape, or if you want just to have the same
address lists available in several mail user agents.

This package is relocatable. That means that if you need any of the
tools included in the package and you are not the administrator at your
site, you should be able to install the package locally to your homedir,
without having root-permissions, and use the tools. Read RPM
documentation on how to do so.

%description addrbk-tools -l ru_RU.KOI8-R
    -- ,    Pine
    (contributions)    
.     ,      %name
     ,  
  (mail user agents --  
)   .     
.

  %name-addrbk-tools,     
 Mutt, elm, mail, Netscape   %name (
)            
 ( )     .

    (relocatable).      ,
     -   ,  
   ,      
   .    -- .  RPM.

%prep
%setup -q -n %name%baseversion -a 8
%patch5 -p1 -b .filter
%patch21 -p1 -b .filter-reset

pushd imap
%patch1 -p1 -b .glibc-time
%patch4 -p1 -b .ALT

%patch10 -p1 -b .deb-port
%patch11 -p1 -b .deb-nonull
#patch12 -p1 -b .deb-blackbox
%patch13 -p1 -b .overflow

%patch6 -p1 -b .flock

%if %WithMaildir
%patch8 -p1 -b .maildir
%endif
 
%patch9 -p2 -b .forPine
%patch2 -p1 -b .glibc-time
%patch17 -p1 -b .ssl
popd

%if "%update" != "2.0"
%patch7 -p1 -b .tinfo
%endif
#% patch15 -p1 -b .cclientdir
patch -p1 --suffix=.cclientdir --fuzz=3 < %PATCH15

%patch14 -p1

%patch20 -p1

%patch120 -p1 -b .buildconf
%patch121 -p1 -b .path

%if %WithRecode

pushd pine
 tar xvf %SOURCE50
popd

patch -p1 --suffix=.fuzzyLev --fuzz=3 < %PATCH131
patch -p1 pine/pine.h <<'EOF'
@@ -63,7 +63,7 @@
 #ifndef _PINE_INCLUDED
 #define _PINE_INCLUDED

-#define PINE_VERSION		"%baseversion"
+#define PINE_VERSION		"%fullversion"
 #define	PHONE_HOME_VERSION	"-count"
 #define	PHONE_HOME_HOST		"docserver.cac.washington.edu"

EOF
%patch130 -p1 -b .Lev

%endif

# utils:
install -p -m755 %SOURCE101 contrib/utils/elm2pine
install -p -m755 %SOURCE102 contrib/utils/pine2Mutt

# just in case this wants /usr/local/bin/perl
find contrib -type f |
	xargs fgrep -l /usr/local/bin/perl |
	xargs perl -pi -e 's|/usr/local/bin/perl|%_bindir/perl|'

%setup -qDT -a103 -n %name%baseversion
pushd ldif2pine-%ldifver
for n in ldif2pine; do
  { echo '#!%_bindir/perl -w'; cat $n.pl; } > $n
done
popd

%build
# force re-confinguration:
#%__rm imap/OSTYPE

# 1. mbox driver can be excluded here
# 2. SSLCERTS path can be set here
MAKEFLAGS="$MAKEFLAGS --print-directory" \
./build \
%if !%WithDebug
    DEBUG="" \
%endif
    OPTIMIZE="$RPM_OPT_FLAGS" \
%if %WithSSL
    SSLTYPE=unix \
%else
    SSLTYPE=none \
    NOSSL \
%endif
%if %WithMaildir
    EXTRADRIVERS='mbox maildir' \
%else
    EXTRADRIVERS='mbox' \
%endif
    EXTRASPECIALS='MAILSPOOL=%mailspooldir SSLDIR=%_ssldir SSLINCLUDE=/usr/include SSLLIB=/usr/lib SSLCERTS=%_pemdir' \
    lnp

# mbox is turned on by default, so we 
# do not need an %%else case for %%if %%WithMaildir here


# Making docs
pushd doc
%__rm -f tech-notes.txt

pushd tech-notes
  make
  # preparing for install:
  #targetDir=$RPM_BUILD_ROOT%_docdir/%name-%fullversion-%release/tech-notes
  # Let's see how %doc will pack it:
  txtDir=tech-notes
  htDir=tech-notes/HTML
  mkdir -p "$txtDir" "$htDir"
  for n in *.html; do
    %__install -p -m0644 "$n" "$htDir/$n"
	txtn="${n%.html}.txt"
    %__install -p -m0644 "$txtn" "$txtDir/$txtn"
  done
  for n in tech-notes.txt; do
    %__rm -f "$n"; %__install -m0644 -p %SOURCE15 "$n"
  done
popd

popd
# end making docs

%install
%__mkdir_p "$RPM_BUILD_ROOT"{%_bindir,%_libdir,%_docdir,%_mandir/man1}

# data: perhaps put it in shared?
install -p -m644 doc/mime.types $RPM_BUILD_ROOT%_libdir/mime.types

# binaries
for n in pi{ne,co,lot} rp{dump,load}; do
    install -p -m755 bin/$n $RPM_BUILD_ROOT%_bindir/$n
done

# config files
install -p -m644 -D %SOURCE2 $RPM_BUILD_ROOT%_sysconfdir/pine.conf
install -p -m644 -D %SOURCE3 $RPM_BUILD_ROOT%_sysconfdir/pine.conf.fixed
cat >> $RPM_BUILD_ROOT%_sysconfdir/pine.conf.fixed <<EOF
# Full name for "local support" address used by "Report Bug" command.
# Default: Local Support
local-fullname=%packagerName

# Email address used to send to "local support".
# Default: postmaster
local-address=%packagerAddress
EOF

# man-pages
for n in pi{ne,co,lot}.1 rp{dump,load}.1; do
    %__install -p -m644 "doc/$n" "$RPM_BUILD_ROOT"%_mandir/man1
done

%if %WithRecode

# pine-info: also a kind of data mixed with docs - shared?
{
  echo -e "You are probably using PINE %fullversion configured for %distribution.\n"
  %__cat %SOURCE12
} > "$RPM_BUILD_ROOT"%_libdir/pine.info

# overriding the source with a symlink - requires a hack in the %files 
# section, otherwise it will be copied, not linked
%__ln_s -f %_libdir/pine.info doc/pine.info

%endif

# docs:
bzcat %SOURCE11 | tar x
pushd doc

install -p -m644 -D %SOURCE13 ALT-packaging-info
install -p -m644 -D %SOURCE14 README.addrbk-tools

# Rename txt files that we don't want to be included in the main
# package:
for n in FAQs; do
  mv "$n.txt" "$n"
done

%__install -m0644 -p %SOURCE16 FAQ.where
popd

# icons
%__install -p -m644 -D %SOURCE5 $RPM_BUILD_ROOT%_miconsdir/%name.xpm
%__install -p -m644 -D %SOURCE6 $RPM_BUILD_ROOT%_iconsdir/%name.xpm
%__install -p -m644 -D %SOURCE7 $RPM_BUILD_ROOT%_liconsdir/%name.xpm

# (fg) Menu entry 1 (pine)
mkdir -p $RPM_BUILD_ROOT%_menudir
cat >$RPM_BUILD_ROOT%_menudir/%name <<EOF
?package(%name):\\
	command="%exec"\\
	needs="text"\\
	icon="%name.xpm"\\
	section="%section"\\
	title="%name"\\
	longtitle="%name: %mainsummary"
EOF

# (fg) Menu entry 2 (pico)
mkdir -p $RPM_BUILD_ROOT%_menudir
cat >$RPM_BUILD_ROOT%_menudir/pico <<EOF
?package(%name):\\
	command="%_bindir/pico"\\
	needs="text"\\
	icon="%name.xpm"\\
	section="Applications/Editors"\\
	title="pico"\\
	longtitle="pico: default editor for pine"
EOF

# utils:
for n in pine2Mutt elm2pine; do
  %__install -p -m0755 "contrib/utils/$n" "$RPM_BUILD_ROOT"%_bindir/"$n"
done

for n in brk2pine; do
  %__install -p -m0755 "contrib/utils/$n.sh" "$RPM_BUILD_ROOT"%_bindir/"$n"
done

for n in ldif2pine-%ldifver/ldif2pine; do
  %__install -p -m0755 "$n" "$RPM_BUILD_ROOT"%_bindir
done

for n in "%_libdir/pwd2pine"; do
 %__install -p -m0644 "contrib/utils/$(basename "$n")" "$RPM_BUILD_ROOT$n"
 %__install -p -m0755 %SOURCE110 "$RPM_BUILD_ROOT%_bindir/$(basename "$n")"
done

%post
## add menu entry
%update_menus

%if %MergeConfPostInstall

# Set up system-wide defaults for pine by merging the config file
# already present in the system with some new settings. (The old
# settings are appended at the end of the new, so that the old ones
# override the new.)
# All this is just cosmetic.
# The enormous script is rather ugly. A better solution would be to
# teach pine to accept multiple additive feature-lists in one file.
# And to let it verify the set of options.

function collectItems() {
local SORT
if [[ "$1" == "-nosort" ]]; then
    SORT=cat; shift
else
    SORT='sort -u'
fi

local listID="$1"
local moved_msg="${2:-'Moved by RPM'}"

local first="^$listID="
local last='[^,]$'

local readItems="$(mktemp "$listID.XXXXXX")"

  sed -e "
      /$first\$/ b moved
      /$first.*$last/  b item
      /$first/,/$last/ b item
      b
      : item
        w $readItems
      : moved
        s/^/#$moved_msg: /
	"
    echo
    cat $readItems \
    | sed -e "
        s/$first/ /
        s/^[[:space:]]*\$//
        s/^[[:space:]]\+/ /
        s/$last/&,/
      " \
    | $SORT \
    | cat --squeeze-blank \
    | sed -e "
        1  s/^[[:space:]]*/$listID=/
        \$ s/,\$//
      "
    rm -f "$readItems"
}

echo $"Re-generating system-wide config files on the base of the old ones:"
for n in %_sysconfdir/pine.conf; do
  old="$n.rpmorig"
  new="$n.rpmnew"

  if [[ -e "$new" ]]; then cp -f "$new"{,.last}; fi

  echo -n "$n: "
  {
    cp -f "$n" "$old"

    filter=''
    for listID in feature-list '-nosort url-viewers'; do
      filter="$filter | collectItems $listID"
    done
    eval "cat '$new' '$old' 2> /dev/null" "$filter" > "$n"
    unset filter

    if [[ "$n" == %_sysconfdir/pine.conf ]]; then
      %exec -conf > "$new" && mv -f "$new" "$n"
    fi

    # We do not need an identical file saved in $old
    if diff -q "$old" "$n" &> /dev/null; then
      rm -f "$old"
    else
      printf $"original saved to %s, " "$old"
    fi
  } && echo -e $"\tre-generated successfully :-)" \
    || echo $"\tre-generation failed :-("
  unset old new
done

%endif

%postun
## remove menu entry
%clean_menus

%files
%doc README CPYRIGHT doc/{*.txt,mailcap.unx,FAQ.where} contrib/bitmaps imap/docs/bugs.txt
# special docs:
# (RE):
%doc doc/ALT-packaging-info
%doc doc/tech-notes/tech-notes.txt
%doc doc/credits.html

%_bindir/pine
%_bindir/pico
%_bindir/pilot
%_bindir/rpdump
%_bindir/rpload
%_mandir/man1/*
%attr(0644,root,root)	%_libdir/mime.types

%if %WithRecode
%attr(0644,root,root)	%config(missingok) %_libdir/pine.info
# I like the "--no-dereference hack" ;-)
%doc --no-dereference doc/pine.info
%endif

%attr(0644,root,root)	%config(noreplace) %_sysconfdir/pine.conf
%attr(0644,root,root)	%config(noreplace) %_sysconfdir/pine.conf.fixed

%_menudir/%name
%_menudir/pico
%_iconsdir/%name.xpm
%_miconsdir/%name.xpm
%_liconsdir/%name.xpm

%files doc
%doc doc/{tutorial.4,FAQs,faq}
%doc doc/tech-notes/tech-notes
%doc doc/{pine-ports,pine-info.txt}
%doc doc/{project-history,changes}.html

%files addrbk-tools
%doc doc/README.addrbk-tools ldif2pine-%ldifver/*.txt
%attr(0755,root,root) %_bindir/*2pine
%attr(0755,root,root) %_bindir/pine2*
%attr(0644,root,root) %_libdir/pwd2pine

%changelog
* Mon May 10 2004 ALT QA Team Robot <qa-robot@altlinux.org> 4.58L-alt2.1
- Rebuilt with openssl-0.9.7d.

* Mon Nov  3 2003 Ivan Zakharyaschev <imz@altlinux.ru> 4.58L-alt2
- the changes are merely in packaging:
  + merge the spec/patches for ALT Master 2.0 updates 
    (by a tweak/trick in pine-4.58L-alt2-0.4.1.diff);
  + fix non-Latin characters in English description.

* Mon Sep 15 2003 Ivan Zakharyaschev <imz@altlinux.ru> 4.58L-alt1
- new upstream version (various fixes, among them for the 2 vulnerabilities
  described at http://www.idefense.com/advisory/09.10.03.txt):
  + patches incorporated into the upstream release: 22 (mbox-inbox),
    10 (partially uw-imap-2001a-debian-portability for os_lnx.h);
  + redone patches: 17 (uw-imap-2002-alt-openssl), the L diff;
  + updated docs;
- pine-addrbk-utils' "Requires" updated.

* Sat May 10 2003 Ivan Zakharyaschev <imz@altlinux.ru> 4.55L-alt2
- use some new features in the system-wide configuration (color signature,
  warn-if-blank-subject and -to-or-cc);
- update docs;
- add a note on the conflict between recoding 
  and the native Pine's conversion facilities;

* Sat May 10 2003 Ivan Zakharyaschev <imz@altlinux.ru> 4.55L-alt1
- new upstream version + upstream patch for it (bug fixes and new features:
  view: http://www.washington.edu/pine/changes/4.53-to-4.55.html);
- minor changes in the L-extension (recoding);

* Fri May  9 2003 Ivan Zakharyaschev <imz@altlinux.ru> 4.53L-alt2
- L-extension 0.4.0 (recoding):
  + fix Formatted Save ($) command dialog;
  + fix crash when replying to a recoded message;
  + fix crash when working with formatted saved msgs with recoded headers;
  + add support for smart autorecoding of rfc1522-strings (used in headers);
  + if formatted-save-stop-recode is on, bring Pine to the auto-recode mode 
    after a formatted save operation ($);
  + introduce "brute recoding of headers" mode (^R H) on top of the 
    normal "smart" recoding; it replaces the obsolete 
    "recode-header" configuration option present in previous releases;
  + change internals of the Pine-filter-recoding interaction:
    store the recoding pipe per filter;
  + other enhancements in the internals;
- spec: %%add_optflags %%optflags_debug for the normal build 
  (will be stripped at the end by rpm; useful for debugging);

* Thu Jan 23 2003 Ivan Zakharyaschev <imz@altlinux.ru> 4.53L-alt1
- new upstream version: fixes a bug with filter rules matching and actions
 (see Release Notes in the Main Menu 
 or http://www.washington.edu/pine/changes.html).

* Fri Jan 10 2003 Ivan Zakharyaschev <imz@altlinux.ru> 4.52L-alt1
- new upstream version: it does not introduce major new functionality,
  it addresses bugs found in earlier versions (see Release Notes in
  the Main Menu or http://www.washington.edu/pine/changes.html):
  + patch130 (Lev's recode) - redone;
  + docs - updated.

* Tue Dec 31 2002 Ivan Zakharyaschev <imz@altlinux.ru> 4.51L-alt2
- pine.conf: disable-charset-conversions, disable-2022-jp-conversions
  (disable the built-in recoding, added in 4.50 upstream;
  ALT's recoding is more universal -- it supports multibyte encodings).

* Sun Dec 29 2002 Ivan Zakharyaschev <imz@altlinux.ru> 4.51L-alt1
- new upstream version, patches changed:
  + patch12 (deb-blackbox) - not applied (as in Debian);
  + patch18 (client address logging) - is upstream;
  + patch19 (buffer overflow in body structure extension) - upstream;
  + patch17 (SSL paths) - redone;
  + patch120 (build conf) - redone;
  + patch130 (Lev's recode) - redone;
  + docs - updated.

* Fri Oct 18 2002 Ivan Zakharyaschev <imz@altlinux.ru> 4.44L-alt4
- Added 2 utilities: rpdump, rpload -- for Pine Remote data management
- link against libtinfo instead of libncurses
- (synced with uw-imap-2001a-alt8)
- follow the SSLDIR relocation:
  + set %%_ssldir according openssl-config output (/var/lib/ssl now)
  + fix docs
- use %_var/mail/ as the mailbox directory (instead of /var/spool/mail/) 
  as FHS requires

* Fri Oct 18 2002 Ivan Zakharyaschev <imz@altlinux.ru> 4.44L-alt3.1.1
- (synced with uw-imap-2001a-alt5.1.1)
- Fixed: 
  + locking on reiserfs (#0001400 at bugs.altlonux.ru): make the locking 
    routine work on all kinds of FS through fcntl(2), and make it not silently 
    be a no-op (always issue a warning if locking is disabled)
  + client address logging in server_init() (thanks to Andrey Khavryuchenko 
    <akhavr at kds.com.ua> and RH: #60290 at bugzilla.redhat.com)
  + libc-client's support for a certain IMAP extension 
    (not supported by UW imapd yet; more info inside patch16)
- spec-file (no impact on the binaries):
  + pass SSLCERTS directory in %%build

* Tue May 14 2002 Ivan Zakharyaschev <imz@altlinux.ru> 4.44L-alt3
- spec-file: 
    + change the %%With* macros a bit;
    + enable defining %%release in command line;

* Tue May  7 2002 Ivan Zakharyaschev <imz@altlinux.ru> 4.44L-alt2
- code fixes (the same as in uw-imap-2001a-alt3):
  + use flock simulation via fcntl to be consistent with the other part
    of ALT Linux system, fcntl's error processing changed (flocksim.patch);
  + two potential SegFaults (in message parsing -- patch13;
    and working with a specific blackbox config -- patch11);
- more ALT Linux (and RedHat- and Debian-like, FHS complaint) system specific
  customization (several patches merged):
  + change paths to the server binaries in configuration and docs;

* Sun Jan 13 2002 Ivan Zakharyaschev <imz@altlinux.ru> 4.44L-alt1
- new upstream version (4.44): security bug fixed ("URL handler
  allows embedded commands")
- config options updated (suggestions by Michael Shigorin <mike@lic145.kiev.ua>)
- for packagers: patches and various build options (make args, defines)
  synced with uw-imap pkg (no major changes)

* Fri Nov 30 2001 Ivan Zakharyaschev <imz@altlinux.ru> 4.43L-alt1
- new upstream version (4.43)

* Fri Nov 30 2001 Ivan Zakharyaschev <imz@altlinux.ru> 4.42L-alt3
- charset-editorial for autorecoded messages 
- URL-viewing via url_handler.sh from urlview pkg (originally for Mutt)
- update docs
- for packagers: the postinstall script whose task is to merge config-files 
  now can either sort alphabetically a list of Pine options or not (these
  variants are used for feature-list and url-viewers).

* Fri Nov 23 2001 Ivan Zakharyaschev <imz@altlinux.ru> 4.42L-alt2
- recoding engine improved to support multibyte charsets

* Fri Nov 23 2001 Ivan Zakharyaschev <imz@altlinux.ru> 4.42L-alt1
- new version: 4.42
- for packagers:
  + some old patches removed, most of others redone
  + paths for SSL build are now set in the the call of ./build in
    %%build (and the Makefiles are not patched as before)
  + some texts moved out of the spec into separate files
  + imap-vfs.patch thrown away
  + do not apply all the flock-patches

* Thu Mar 01 2001 Ivan Zakharyaschev <vanyaz@mccme.ru> 4.33L-ipl2mdk
- now builds on glibc 2.2.2 (two trivial patches: for imap -- from
  RedHat people & for maildir module)
- two simple cosmetic patches from the authors (21, 22)
- Changes in the spec-file:
  + maildir patch splitted into three pieces: the module, a patch that
    "embeds" it into the main source tree and pine-specific (not server)
    defs.
  + warning about Maildir added to the description
  + Russian summaries and descriptions commented out
  + no need for explicit unsetting locale before build -- done by rpm now

* Sun Feb 25 2001 Ivan Zakharyaschev <vanyaz@mccme.ru>
- some fixes in menu entries' fields

* Fri Feb 02 2001 Ivan Zakharyaschev <vanyaz@mccme.ru> 4.33L-ipl1mdk
- new source, a pair of patches redone (maildir, imap related)
- some new docs from UW
- openssl patch splitted in two (to share it with imap)
- sparc patch thrown away

* Tue Jan 23 2001 Ivan Z. <vanyaz@mccme.ru> 4.32L-ipl4mdk
- descriptions changed a bit
- "regeneration script": localized messages ($".."), don't make a copy
  identical to the newly created file

* Sun Jan 21 2001 Ivan Z. <vanyaz@mccme.ru> 4.32L-ipl3mdk
- small changes in pine.conf (to make it differ)
- cleanup_spec
- unset LANG and others before building pine
- Russian summaries & descriptions

* Fri Jan 19 2001 Ivan Z. <vanyaz@mccme.ru> 4.32L-ipl2mdk
- pine.conf generating script rewritten

* Thu Jan 18 2001 Ivan Z. <vanyaz@mccme.ru> 4.32L-ipl1mdk
- new source

* Mon Dec 25 2000 Dmitry V. Levin <ldv@fandra.org> 4.31L-ipl2mdk
- Build with openssl support (openssl-0.9.6-ipl1mdk).

* Wed Dec 13 2000 Ivan Z. <vanyaz@mccme.ru> 4.31L-ipl1mdk
  - new version
  - temporarily build without ssl (without patching imap);
    will return it back after some corrections
  - confvar, segfix, sparc patches not needed any more
  - fuzzy parts of L-patch moved to other places: adding L-suffix to the
    version in pine.h by a patch inside the spec-file; a special patch
	for relnotes
  - wmconfig finally removed

* Wed Nov 22 2000 Ivan Z. <vanyaz@mccme.ru> 4.30-ipl2mdk
  - bzip2 ps in doc/GettingStarted (perhaps make all the additional docs
	a separate subpackage?)
  - make a subpackage for docs (1.5M)

* Mon Nov 20 2000 Ivan Z. <vanyaz@mccme.ru>
  - tools package made relocatable (is it good?)
  - some verification types aren't performed on config files (useless because
	they are generated in post-install)

* Sun Nov 19 2000 Ivan Z. <vanyaz@mccme.ru>
  - post-install script now merges feature-lists of new and old config
	files before by concatenating them as whole files
  - some utilities added; the subpackage renamed (there will be a
	separate package for mailbox tools).

* Sat Nov 18 2000 Ivan Z. <vanyaz@mccme.ru>
  - direct merge with RedHat:
	+ work around a compiler bug on ia64 (do we need this anymore?)
	+ set rsh-open-timeout to 0

* Fri Nov 17 2000 Ivan Z. <vanyaz@mccme.ru>
- Almost all patches and icons bunzipped (that makes srpm's smaller!)
- Structure and install procedure of additional sources re-organized
- (RE) Lev's extension improved (L-2_2):
  + charset naming system in rules the same as in the rest of PINE;
  + Paratype-154 (Asian Cyrillic) added
- (RE) README.ipl gets fuller
- the old pine.wmconfig added to docs (contrib/)
- performing build in C locale (to get "C" dates)
- full version macro defined (a means of striking the subpackage
  overriding version-macro)

* Wed Nov 15 2000 Ivan Z. <vanyaz@mccme.ru>
- (RE) README.ipl written
- give up attempts setting the display charset automatically
- our (RE) "path" and "build" patches absorbed similar new patches
  from Mdk/RH
- "noreplace" not set for pine.conf, 'cause it's re-generated
- merged with Mdk (Cooker), which in its turn has merged with RH
  (not all changes migrated, differences are mentioned above):

###############################
# begin insertion from Mandrake

* Fri Nov 10 2000 Vincent Danen <vdanen@mandrakesoft.com> 4.30-3mdk
- merge with Red Hat
- use lnp (PAM auth) instead of slx (crypt)
- some spec fixes
- enable SSL
- make config files noreplace
- added large icon
- bzip patches and icons

* Thu Nov 09 2000 Vincent Danen <vdanen@mandrakesoft.com> 4.30-2mdk
- patch to correct pine crashing and check extra NULL pointers from RH

* Tue Nov 07 2000 Vincent Danen <vdanen@mandrakesoft.com> 4.30-1mdk
- 4.30
- security fix for incoming mailbox handling
- remove hardcoded icon directory in menus

# end of insertion from Mandarke
################################

* Thu Nov 07 2000 Ivan Z. <vanyaz@mccme.ru> 4.30-ipl1mdk
- a separate package for utilities (only those that make
  sense with the newest Pine version; they were taken from contrib/utils
  in the source tree and other references in the FAQs)
- documentation brought into order (added local and native, downloaded from UW info)
- A patch from RH (an advanced substitute for the "DEBUG" patch
  (supplied by Trond Eivind Glomsrd <teg@redhat.com>)

* Sat Nov 4  2000 Ivan Z. <vanyaz@mccme.ru>
- configuration files:
  + merging with existed on install,
  + demonstrating new options
  + auto-detecting system console character set
- (RE) Lev's extension adapted and improved (L-2_1):
  + understands "windows-*" encoding names
  + has 7-bit KOI option
- making docs (text and HTML)

* Fri Nov 3  2000 Ivan Z. <vanyaz@mccme.ru>
- Bug fixed: pine now works with no DEBUG compiled in ("init" patch).

* Wed Nov 1  2000 Ivan Z. <vanyaz@mccme.ru>
- The path patches, that were correcting the paths for Mandrake system
 (/var, /etc, no /usr/local), merged into one big patch with my additions.
 In fact, there were three of them: Lev's, RedHat's and "passwd"; I think
 the idea of patching in order to change the pathnames isn't good: better
 to write a script that would process the sources.
- vfs patch re-made for pine4.30.
- a small configuring patch made out of the old RedHat's patch (QUOTAS).

* Sun Oct 29 2000 Ivan Z. <vanyaz@mccme.ru>
- "maildir" patch that has been present in RE was even newer/better than that in Cooker (2 patches)
- two system-wide config files in one tar
- rpm-3.0.6 adaptations:
  + BuildRoot tag removed
  + compression of man-pages removed
  + rm -rf in build root not needed any more
- new version (4.30)
- spell patch was bad (the corrections were wrong), removed
- Lev's patch splitted into two: recoding and path adaptations for Mdk filesystem.
- merged with Cooker (here's the Mandrake's changelog):

###############################
# begin insertion from Mandrake

* Mon Aug 07 2000 Frederic Lepied <flepied@mandrakesoft.com> 4.21-6mdk
- automatically added BuildRequires

* Thu Aug 03 2000 Geoffrey Lee <snailtalk@mandrakesoft.com> 4.21-5mdk
- rebuild for BM
- rebuild with macros
- tmppath
* Sun Apr 09 2000 Denis HAvlik <denis@mandrakesoft.com> 4.21-4mdk
- Group: Networking/Mail
- pine-tree icon + menu entries (for pine + pico)
- spec-helper

* Sat Feb 19 2000 Geoffrey Lee <snailtalk@linux-mandrake.com> 4.21-3mdk
- make patch to change os-lnx.h from /bin/passwd to /usr/bin/passwd

* Tue Dec 14 1999 John Buswell <johnb@mandrakesoft.com>
- add new maildir patches
- add vfs patch
- fixed non-existant directory seek problem (bug:#506)

* Tue Nov 30 1999 Chmouel Boudjnah <chmouel@mandrakesoft.com>
- 4.21.
- Merge with recent redhat changes.

# end of insertion from Mandarke
################################

* Sun Nov 18 1999 AEN <aen@logic.ru>
- new version
- Lev Levitin's <lev@mccme.ru> recoding patch
- build for RE

* Tue Nov 02 1999 John Buswell <johnb@mandrakesoft.com>
- Rebuild and Repackage for oxygen (release 2)

* Thu Oct 14 1999 Bernhard Rosenkraenzer <bero@linux-mandrake.com>
- 4.20
- sync with RH

* Thu Aug 12 1999 Cristian Gafton <gafton@redhat.com>
- add maildir patch

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com>
- auto rebuild in the new build environment (release 2)

* Fri Feb 26 1999 Cristian Gafton <gafton@redhat.com>
- fix buildroot and add cleanup section
- move config files to /etc/pine.conf

* Tue Feb 02 1999 Preston Brown <pbrown@redhat.com>
- turned off .pine-debugX files

* Thu Dec 17 1998 Cristian Gafton <gafton@redhat.com>
- build against glibc 2.1

* Fri Nov 13 1998 Cristian Gafton <gafton@redhat.com>
- patch to enable SIGWINCH processing (why do the pine folks keep
  disabling this stuff?!)

* Fri Oct 09 1998 Cristian Gafton <gafton@redhat.com>
- use termios instead of termio (patch used to be in here...)
- use terminfo instead of termcap and link against ncurses instead of termcap
- supply -lcrypt as a standard lib

* Sat Sep 19 1998 Jeff Johnson <jbj@redhat.com>
- upgrade to 4.04 (compatibility with some client imaps).

* Fri Sep 11 1998 Jeff Johnson <jbj@redhat.com>
- use only fcntl locking.

* Thu Sep 10 1998 Jeff Johnson <jbj@redhat.com>
- update to 4.03

* Fri Aug 14 1998 Jeff Johnson <jbj@redhat.com>
- patch to 4.02A.
- disable stupid EACCESS warnings.

* Wed Jul 22 1998 Jeff Johnson <jbj@redhat.com>
- update to 4.02.

* Mon Apr 27 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Thu Jan 15 1998 Erik Troan <ewt@redhat.com>
- added patch to fix pine filters

* Tue Dec 30 1997 Erik Troan <ewt@redhat.com>
- fixed resizing in pine and pico

* Thu Dec 18 1997 Erik Troan <ewt@redhat.com>
- removed patch for SIGCHLD race -- it shouldn't be necessary
- added patch to avoid longjmp() from SIGCHLD handler -- SIGCHLD handling
  is sane now

* Thu Dec 11 1997 Cristian Gafton <gafton@redhat.com>
- added a patch for handling a SIGCHLD race condition

* Tue Nov 04 1997 Erik Troan <ewt@redhat.com>
- fix for locks w/ long st_dev field
- use termios rather then termio

* Wed Oct 29 1997 Donnie Barnes <djb@redhat.com>
- added wmconfig entry

* Fri Oct 10 1997 Erik Troan <ewt@redhat.com>
- removed exec bit from /usr/doc/pine-3.96-1/contrib/utils/pwd2pine
